@@ -144,6 +144,16 @@ int gweled_gems_fall_into_place (void)
 	return 0;
 }
 
+int gweled_gems_fall_off (void)
+{
+	gint i, j;
+	for (i = 0; i < BOARD_WIDTH; i++)
+		for (j = 0; j < BOARD_HEIGHT; j++)
+			sge_object_fall_to (g_gem_objects[i][j],
+					    480);
+	return 0;
+}
+
 void gweled_draw_board (void)
 {
 	gint i, j;
@@ -712,6 +722,7 @@ gboolean board_engine_loop (gpointer data)
 	{
 		gi_total_gems_removed -= g_steps_for_timer;
 		if (gi_total_gems_removed <= gi_previous_bonus_at) {
+			gweled_gems_fall_off ();
 			gweled_draw_message ("time's up #");
 			gi_game_running = 0;
 			remove(SAVE_PATH);	
@@ -868,6 +879,8 @@ gboolean board_engine_loop (gpointer data)
 				if ((gi_next_bonus_at == FIRST_BONUS_AT) || TIMER_MODE) {
 					gint i, j;
 
+					gweled_gems_fall_off ();
+
 					gweled_draw_game_message ("no moves left #", 1.0);
 					memset (gi_nb_of_tiles, 0, 7 * sizeof (gchar));
 
@@ -893,6 +906,7 @@ gboolean board_engine_loop (gpointer data)
 					gweled_gems_fall_into_place ();
 					gi_state = _MARK_ALIGNED_GEMS;
 				} else {
+					gweled_gems_fall_off ();
 					gweled_draw_message ("no moves left #");
 					gi_game_running = 0;
 					remove(SAVE_PATH);	
